==> apo-ws-client-6.00.50.3-sources.jar: fr/univlorraine/apowsclient/creationSE/LienVetElpLseDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour LienVetElpLseDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="LienVetElpLseDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codElp" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="8"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codEtp" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="6"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codVersionEtp" type="{LienVetElpLseDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullable3Int" minOccurs="0"/&gt;
 *         &lt;element name="codListeElp"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="8"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="nbrMinElp" type="{LienVetElpLseDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullable2Int" minOccurs="0"/&gt;
 *         &lt;element name="nbrMaxElp" type="{LienVetElpLseDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullable2Int" minOccurs="0"/&gt;
 *         &lt;element name="nbrMinCredits" type="{LienVetElpLseDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableDecimal" minOccurs="0"/&gt;
 *         &lt;element name="nbrMaxCredits" type="{LienVetElpLseDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableDecimal" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LienVetElpLseDTO", namespace = "LienVetElpLseDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codElp",
    "codEtp",
    "codVersionEtp",
    "codListeElp",
    "nbrMinElp",
    "nbrMaxElp",
    "nbrMinCredits",
    "nbrMaxCredits"
})
public class LienVetElpLseDTO {

    @XmlElement(nillable = true)
    protected String codElp;
    @XmlElement(nillable = true)
    protected String codEtp;
    @XmlElement(nillable = true)
    protected String codVersionEtp;
    @XmlElement(required = true)
    protected String codListeElp;
    @XmlElement(nillable = true)
    protected String nbrMinElp;
    @XmlElement(nillable = true)
    protected String nbrMaxElp;
    @XmlElement(nillable = true)
    protected String nbrMinCredits;
    @XmlElement(nillable = true)
    protected String nbrMaxCredits;

    /**
     * Obtient la valeur de la propriété codElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodElp() {
        return codElp;
    }

    /**
     * Définit la valeur de la propriété codElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodElp(String value) {
        this.codElp = value;
    }

    /**
     * Obtient la valeur de la propriété codEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtp() {
        return codEtp;
    }

    /**
     * Définit la valeur de la propriété codEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtp(String value) {
        this.codEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codVersionEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVersionEtp() {
        return codVersionEtp;
    }

    /**
     * Définit la valeur de la propriété codVersionEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVersionEtp(String value) {
        this.codVersionEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codListeElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodListeElp() {
        return codListeElp;
    }

    /**
     * Définit la valeur de la propriété codListeElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodListeElp(String value) {
        this.codListeElp = value;
    }

    /**
     * Obtient la valeur de la propriété nbrMinElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbrMinElp() {
        return nbrMinElp;
    }

    /**
     * Définit la valeur de la propriété nbrMinElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbrMinElp(String value) {
        this.nbrMinElp = value;
    }

    /**
     * Obtient la valeur de la propriété nbrMaxElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbrMaxElp() {
        return nbrMaxElp;
    }

    /**
     * Définit la valeur de la propriété nbrMaxElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbrMaxElp(String value) {
        this.nbrMaxElp = value;
    }

    /**
     * Obtient la valeur de la propriété nbrMinCredits.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbrMinCredits() {
        return nbrMinCredits;
    }

    /**
     * Définit la valeur de la propriété nbrMinCredits.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbrMinCredits(String value) {
        this.nbrMinCredits = value;
    }

    /**
     * Obtient la valeur de la propriété nbrMaxCredits.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbrMaxCredits() {
        return nbrMaxCredits;
    }

    /**
     * Définit la valeur de la propriété nbrMaxCredits.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbrMaxCredits(String value) {
        this.nbrMaxCredits = value;
    }

}

==> apo-ws-client-6.00.51.1-sources.jar: fr/univlorraine/apowsclient/creationSE/LienVetElpLseDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour LienVetElpLseDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="LienVetElpLseDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codElp"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="8"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codEtp"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="6"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codVersionEtp" type="{LienVetElpLseDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullable3Int"/&gt;
 *         &lt;element name="codListeElp"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="8"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="nbrMinElp" type="{LienVetElpLseDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullable2Int"/&gt;
 *         &lt;element name="nbrMaxElp" type="{LienVetElpLseDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullable2Int"/&gt;
 *         &lt;element name="nbrMinCredits" type="{LienVetElpLseDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableDecimal"/&gt;
 *         &lt;element name="nbrMaxCredits" type="{LienVetElpLseDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableDecimal"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "LienVetElpLseDTO", namespace = "LienVetElpLseDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codElp",
    "codEtp",
    "codVersionEtp",
    "codListeElp",
    "nbrMinElp",
    "nbrMaxElp",
    "nbrMinCredits",
    "nbrMaxCredits"
})
public class LienVetElpLseDTO {

    @XmlElement(required = true, nillable = true)
    protected String codElp;
    @XmlElement(required = true, nillable = true)
    protected String codEtp;
    @XmlElement(required = true, nillable = true)
    protected String codVersionEtp;
    @XmlElement(required = true)
    protected String codListeElp;
    @XmlElement(required = true, nillable = true)
    protected String nbrMinElp;
    @XmlElement(required = true, nillable = true)
    protected String nbrMaxElp;
    @XmlElement(required = true, nillable = true)
    protected String nbrMinCredits;
    @XmlElement(required = true, nillable = true)
    protected String nbrMaxCredits;

    /**
     * Obtient la valeur de la propriété codElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodElp() {
        return codElp;
    }

    /**
     * Définit la valeur de la propriété codElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodElp(String value) {
        this.codElp = value;
    }

    /**
     * Obtient la valeur de la propriété codEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtp() {
        return codEtp;
    }

    /**
     * Définit la valeur de la propriété codEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtp(String value) {
        this.codEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codVersionEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodVersionEtp() {
        return codVersionEtp;
    }

    /**
     * Définit la valeur de la propriété codVersionEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodVersionEtp(String value) {
        this.codVersionEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codListeElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodListeElp() {
        return codListeElp;
    }

    /**
     * Définit la valeur de la propriété codListeElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodListeElp(String value) {
        this.codListeElp = value;
    }

    /**
     * Obtient la valeur de la propriété nbrMinElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbrMinElp() {
        return nbrMinElp;
    }

    /**
     * Définit la valeur de la propriété nbrMinElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbrMinElp(String value) {
        this.nbrMinElp = value;
    }

    /**
     * Obtient la valeur de la propriété nbrMaxElp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbrMaxElp() {
        return nbrMaxElp;
    }

    /**
     * Définit la valeur de la propriété nbrMaxElp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbrMaxElp(String value) {
        this.nbrMaxElp = value;
    }

    /**
     * Obtient la valeur de la propriété nbrMinCredits.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbrMinCredits() {
        return nbrMinCredits;
    }

    /**
     * Définit la valeur de la propriété nbrMinCredits.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbrMinCredits(String value) {
        this.nbrMinCredits = value;
    }

    /**
     * Obtient la valeur de la propriété nbrMaxCredits.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbrMaxCredits() {
        return nbrMaxCredits;
    }

    /**
     * Définit la valeur de la propriété nbrMaxCredits.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbrMaxCredits(String value) {
        this.nbrMaxCredits = value;
    }

}
